<?php
/**
 * Module Name: Extended Social Media Block
 * Description: Adds more social media links and icons to your navigation area; Designed for the Mystique theme only. Credits for the icons go to <a href="http://marknhewitt.co.uk/my-web-portfolio/mystique-theme-edits/extra-nav-icons-for-the-mystique-theme/" target="_blank">Mark N Hewitt</a>
 * Version: 1.0
 * Author: digitalnature
 * Author URI: http://digitalnature.eu
 */


// class name must follow this pattern (AtomMod + directory name)
class AtomModExtendedSocialMedia extends AtomMod{

  // available public variables from parent class:
  //
  // $this->url  - this module's url path
  // $this->dir  - this module's directory

  public function init(){

    // register extra theme options
    Atom::app()->addDefaultOptions(array(

       // the first 3 already have setting fields in the admin area, but they are disabled by default, so we only need to enable them;
       // we can also overwrite existing default theme setting values here
       'media_facebook'   => '',
       'media_flickr'     => '',
       'media_myspace'    => '',

       // new options, these require new setting fields
       'media_youtube'    => '',
       'media_lastfm'     => '',
    ));

    // hooks
    Atom::add('social_media_links',       array(&$this, 'output'));
    Atom::add('inline_css',               array(&$this, 'css'));     // there's very little css, not worth loading a new stylesheet so we add it inline

    if(is_admin())
      Atom::add('settings_content_media', array(&$this, 'settings'));
  }

  // theme settings fields (for new options only)
  public function settings(){ ?>
    <div class="entry">
      <p><label for="<?php echo ATOM; ?>_media_youtube">YouTube</label></p>
      <input id="<?php echo ATOM; ?>_media_youtube" size="40" name="media_youtube" type="text" value="<?php echo Atom::app()->options('media_youtube'); ?>" />
    </div>

    <div class="entry">
      <p><label for="<?php echo ATOM; ?>_media_lastfm">Last.fm</label></p>
      <input id="<?php echo ATOM; ?>_media_lastfm" size="40" name="media_lastfm" type="text" value="<?php echo Atom::app()->options('media_lastfm'); ?>" />
    </div>
  <?php
  }

  // the output (new options only)
  public function output($links){

    if($k = Atom::app()->options('media_youtube'))
      $links .= '<li class="youtube"><a title="'._a('My YouTube channel').'" href="'.$k.'">YouTube</a></li>';

    if($k = Atom::app()->options('media_lastfm'))
      $links .= '<li class="lastfm"><a title="'._a('My Last.fm profile').'" href="'.$k.'">Last.fm</a></li>';

    return $links;
  }


  // css styles (replaces rss and twitter icons as well)
  public function css($css){
    ob_start();
    ?>

  .social-media .rss a{background: transparent url(<?php echo $this->url; ?>/nav-rss.png) no-repeat center top;}
  .social-media .twitter a{background: transparent url(<?php echo $this->url; ?>/nav-twitter.png) no-repeat center top;}
  .social-media .facebook a{background: transparent url(<?php echo $this->url; ?>/nav-facebook.png) no-repeat center top;}
  .social-media .flickr a{background: transparent url(<?php echo $this->url; ?>/nav-flickr.png) no-repeat center top;}
  .social-media .myspace a{background: transparent url(<?php echo $this->url; ?>/nav-myspace.png) no-repeat center top;}
  .social-media .youtube a{background: transparent url(<?php echo $this->url; ?>/nav-youtube.png) no-repeat center top;}
  .social-media .lastfm a{background: transparent url(<?php echo $this->url; ?>/nav-lastfm.png) no-repeat center top;}

    <?php
    $css .= ob_get_clean();
    return $css;
  }

}
